import React, { useState, useEffect, useRef } from 'react';
import { Form, Input, Button, Table, Row, Col, Select, Modal, DatePicker, Space, message } from 'antd';
import { DeleteOutlined, PlusOutlined } from '@ant-design/icons';
import '@common/common.less';
import apiObj from '@api/index';
import AddRules from './addRules';
import FiledContext from './filed-context';
const { post, api, xPost } = apiObj;
const { RangePicker } = DatePicker;
const { Option } = Select;
function FieldRules() {
    useEffect(() => {
        getRegular()
        getTableName()
        getColumnName()
        getColumnVerifyPage();
    }, []);
    const [addVisible, setAddVisible] = useState(false);         //新增页面显示
    const [logList, setLogList] = useState([]);
    const [total, setTotal] = useState(0);
    const [type, setType] = useState(0);//1新增 2修改
    const [visible, setVisible] = useState(false);
    const [size, setSize] = useState(15);
    const [current, setCurrent] = useState(1);
    const [regularList, setRegularList] = useState([]);//正则式数据
    const [selectedRowKeys, setSelectedRowKeys] = useState([]);
    const [tableList, setTableList] = useState([]);//表名称
    const [colList, setColList] = useState([]);//字段名称
    const [filedDetail, setFiledDetail] = useState(null);//详情数据
    const [params, setParams] = useState({
        pages: 1,
        current: 1,
        size: 15
    });
    const [form] = Form.useForm();
    let data = {
        pages: 1,
        current: 1,
        size: size
    }
    //表格数据
    function getColumnVerifyPage(param) {
        post(api.getColumnVerifyPage, param || params).then((res) => {
            if (res.data.code === 200) {
                const data = res.data.data;
                setLogList(data.records);
                setTotal(data.total)
            }
        })
    }
    //获取正则式名称
    function getRegular(name) {
        const param = {
            name: name || ''
        }
        post(api.getRegular, param).then((res) => {
            if (res.data.code === 200) {
                const data = res.data.data;
                setRegularList(data);
            }
        })
    }
    //获取字段名
    function getColumnName(columnCname, columnEname) {
        const param = {
            columnCname: columnCname,
            columnEname: columnEname
        }
        post(api.getColumnName, param).then((res) => {
            if (res.data.code === 200) {
                const data = res.data.data;
                setColList([...data]);
            }
        })
    }
    //获取表名称
    function getTableName(tableCname, tableEname) {
        const param = {
            tableCname: tableCname,
            tableEname: tableEname
        }
        post(api.getTableName, param).then((res) => {
            if (res.data.code === 200) {
                const data = res.data.data;
                setTableList([...data]);
            }
        })
    }
    //表名称搜索(中文)
    function cnameSearch(val) {
        getTableName(val, '')
    }
    //表名称搜索(英文)
    function enameSearch(val) {
        getTableName('', val)
    }
    //字段名称搜索(中文)
    function colmeSearch(val) {
        getColumnName(val, '')
    }
    //字段名称搜索(英文)
    function coleneSearch(val) {
        getColumnName('', val)
    }
    //正则式名称搜索
    function onSearch(val) {
        getRegular(val)
    }
    //删除记录
    function delColumnVerify() {
        post(api.delColumnVerify, { ids: selectedRowKeys }).then((res) => {
            if (res.data.code === 200) {
                //刷新列表
                getColumnVerifyPage()
                message.success(res.data.msg);
            } else {
                message.warning(res.data.msg || '操作失败，请重试~');
            }
        });
        showDelModal(false);
    }
    //删除弹窗确认
    function showDelModal(flag) {
        if (flag && !selectedRowKeys.length) {
            message.warning("请先选择要删除的记录~", 1);
            return;
        }
        setVisible(flag)
    }
    //新增修改跳转
    function showModal(type, id) {
        setAddVisible(true)
        setType(type)
        if (type == 1) {
            setFiledDetail({
                columnList: [{
                    columnCname: undefined,
                    columnEname: undefined,
                    ableCname: undefined,
                    tableEname: undefined,
                    id: undefined
                }],
                standardValueList: [{
                    tit: null
                }]
            })
        } else {
            getByIdColumnVerify(id)
        }

    }
    //详情
    function getByIdColumnVerify(id) {
        const param = {
            columnId: id,
        }
        post(api.getByIdColumnVerify, param).then((res) => {
            if (res.data.code === 200) {
                const data = res.data.data;
                const arr = {
                    columnList: [{
                        columnCname: data.columnCname,
                        columnEname: data.columnEname,
                        tableCname: data.tableCname,
                        tableEname: data.tableEname,
                        id: data.id
                    }],
                    standardValueList: [{
                        tit: data.standardvalue,
                    }],
                    ...data
                }
                setFiledDetail(arr)
            }
        })
    }
    function onSizeChange(current, pageSize) {
        params.current = current
        params.size = pageSize
        setSize(pageSize)
        setCurrent(current)
        setParams(params)
        getColumnVerifyPage()
    }
    function changePage(page, pageSize) {
        params.current = page
        params.size = pageSize
        setParams(params)
        setCurrent(page)
        getColumnVerifyPage()
    }
    function onSelectChange(selectedRowKeys) {
        setSelectedRowKeys(selectedRowKeys);
    };
    //返回
    function goBack() {
        setAddVisible(false);
    }
    const onFinish = (value) => {
        const param = {
            ...data,
            ...value,
        }
        setCurrent(1)
        setParams(param)
        getColumnVerifyPage(param);
    };
    const onReset = () => {
        setCurrent(1)
        setParams(data)
        form.resetFields();
        getColumnVerifyPage(data);
    };
    const columns = [
        { title: '序号', dataIndex: 'index', render: (text, record, index) => (current - 1) * params.size + index + 1, width: 60 },
        { title: '表名称（中文）', dataIndex: 'tableCname', key: 'tableCname', width: 130, },
        { title: '表名称（英文）', dataIndex: 'tableEname', key: 'tableEname', width: 130, },
        { title: '字段名称（中文）', dataIndex: 'columnCname', key: 'columnCname', width: 145, },
        { title: '字段名称（英文）', dataIndex: 'columnEname', key: 'columnEname', width: 145, },
        {
            title: '是否必填', dataIndex: 'isRequired', key: 'isRequired', render: (text, record) => {
                return record.isRequired == 1 ? "是" : record.isRequired == 0 ? "否" : '';
            }
        },
        { title: '标准值维护', dataIndex: 'standardvalue', key: 'standardvalue', width: 110 },
        { title: '正则式名称', dataIndex: 'regular', key: 'regular', width: 110 },
        { title: '说明', dataIndex: 'description', key: 'description' },
        {
            title: '操作', dataIndex: 'key', render: (text, record) => (
                <Space size="middle">
                    <a onClick={() => showModal(2, record.columnId)}>修改</a>
                </Space>
            )
        }
    ];
    const rowSelection = {
        selectedRowKeys,
        onChange: onSelectChange,
    };
    if (addVisible && filedDetail) {
        return (
            <FiledContext.Provider value={{ type, detail: filedDetail }}>
                <AddRules back={goBack} />
            </FiledContext.Provider>
        )
    }
    return (
        <div className="wrapper">
            <div className="filter-box">
                <Form
                    form={form}
                    name="normal_login"
                    onFinish={onFinish}
                    initialValues={{ lossType: '', lossWay: '', isRequired: '' }}
                >
                    <Row gutter={24}>
                        <Col span={6} key={0}>
                            <Form.Item label="表名称（中文）" name="tableCname">
                                <Select showSearch allowClear onSearch={cnameSearch} placeholder="请选择">
                                    {tableList.map((item) => {
                                        return (
                                            <Option value={item.tableCname} key={item.tableCname}>{item.tableCname}</Option>
                                        )
                                    })}
                                </Select>
                            </Form.Item>
                        </Col>
                        <Col span={6} key={1}>
                            <Form.Item label="表名称（英文）" name="tableEname">
                                <Select showSearch allowClear onSearch={enameSearch} placeholder="请选择">
                                    {tableList.map((item) => {
                                        return (
                                            <Option value={item.tableEname} key={item.tableEname}>{item.tableEname}</Option>
                                        )
                                    })}
                                </Select>
                            </Form.Item>
                        </Col>
                        <Col span={6} key={2}>
                            <Form.Item label="字段名称（中文）" name="columnCname">
                                <Select showSearch allowClear onSearch={colmeSearch} placeholder="请选择">
                                    {colList.map((item) => {
                                        return (
                                            <Option value={item.columnCname} key={item.columnCname}>{item.columnCname}</Option>
                                        )
                                    })}
                                </Select>
                            </Form.Item>
                        </Col>
                        <Col span={6} key={3}>
                            <Form.Item label="字段名称（英文）" name="columnEname">
                                <Select showSearch allowClear onSearch={coleneSearch} placeholder="请选择">
                                    {colList.map((item) => {
                                        return (
                                            <Option value={item.columnEname} key={item.columnEname}>{item.columnEname}</Option>
                                        )
                                    })}
                                </Select>
                            </Form.Item>
                        </Col>
                        <Col span={5} key={4}>
                            <Form.Item label="是否必填" name="isRequired">
                                <Select
                                    placeholder="请选择"
                                    allowClear
                                >
                                    <Option value="" key={2}>全部</Option>
                                    <Option value="1" key={1}>是</Option>
                                    <Option value="0" key={0}>否</Option>
                                </Select>
                            </Form.Item>
                        </Col>
                        <Col span={5} key={5}>
                            <Form.Item label="标准值" name="standardValue">
                                <Input placeholder="标准值" autoComplete='off' maxLength='30'/>
                            </Form.Item>
                        </Col>
                        <Col span={5} key={6}>
                            <Form.Item label="正则名称" name="regularName">
                                <Select showSearch allowClear onSearch={onSearch} placeholder="请选择">
                                    {regularList.map((item) => {
                                        return (
                                            <Option value={item.name} key={item.id}>{item.name}</Option>
                                        )
                                    })}
                                </Select>
                            </Form.Item>
                        </Col>
                        <Col span={6} key={7}>
                            <Form.Item>
                                <Button type="primary" htmlType="submit">
                                    查询
                                </Button>
                                <Button onClick={onReset}>
                                    重置
                                </Button>
                            </Form.Item>
                        </Col>
                    </Row>
                </Form>
            </div>

            <div className="table">
                <div className="table-header">
                    <h2 className="table-title">字段校验规则维护</h2>
                    <Space size="middle">
                        <Button type="primary" icon={<PlusOutlined />} onClick={() => showModal(1)}>新增</Button>
                        <Button type="primary" onClick={() => showDelModal(true)} danger>删除</Button>
                    </Space>

                </div>

                <Table
                    columns={columns}
                    rowSelection={rowSelection}
                    scroll={{ y: 'calc(100vh - 400px)' }}
                    dataSource={logList}
                    rowKey={record => record.columnId}
                    pagination={{
                        pageSize: size,
                        size: 'small',
                        current: current,
                        showSizeChanger: true,
                        pageSizeOptions: ['15', '30', '60', '120'],
                        showTotal: (total, range) => `第${range[0]}-${range[1]} 条/共 ${total} 条数据`,
                        onShowSizeChange: (current, pageSize) => onSizeChange(current, pageSize), // 改变每页数量时更新显示
                        onChange: (page, pageSize) => changePage(page, pageSize),//点击页码事件
                        total: total
                    }} />
            </div>
            <Modal
                title="删除字段校验规则"
                okText='确定'
                cancelText='取消'
                width={400}
                visible={visible}
                onOk={delColumnVerify}
                /*confirmLoading={confirmLoading}*/
                onCancel={() => showDelModal(false)}
            >
                <p>字段校验规则删除后将无法恢复，确认删除这{selectedRowKeys.length}条变更记录？</p>
            </Modal>
        </div >
    )
}

export default FieldRules;